summaryrefslogtreecommitdiff
path: root/commands.c
diff options
context:
space:
mode:
authorRoland McGrath <roland@redhat.com>1993-09-17 04:46:36 +0000
committerRoland McGrath <roland@redhat.com>1993-09-17 04:46:36 +0000
commit9fc36f735856db7655e10036fab7b8090d65d271 (patch)
tree0b9b6c02a755c4462412164ad2913ddfcf2dad95 /commands.c
parentec2751c045738d27e64072d7dfc9c307e4877e64 (diff)
downloadgunmake-9fc36f735856db7655e10036fab7b8090d65d271.tar.gz
Formerly commands.c.~19~
Diffstat (limited to 'commands.c')
-rw-r--r--commands.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/commands.c b/commands.c
index 1cfe0cf..cd71178 100644
--- a/commands.c
+++ b/commands.c
@@ -409,8 +409,8 @@ delete_child_targets (child)
if (child->deleted)
return;
- /* Delete the file unless it's precious. */
- if (!child->file->precious
+ /* Delete the file unless it's precious or not actually a file (phony). */
+ if (!child->file->precious && !child->file->phony
&& stat (child->file->name, &st) == 0
&& S_ISREG (st.st_mode)
&& (time_t) st.st_mtime != child->file->last_mtime)
@@ -423,7 +423,7 @@ delete_child_targets (child)
/* Also remove any non-precious targets listed
in the `also_make' member. */
for (d = child->file->also_make; d != 0; d = d->next)
- if (!d->file->precious)
+ if (!d->file->precious && !d->file->phony)
if (stat (d->file->name, &st) == 0
&& S_ISREG (st.st_mode)
&& (time_t) st.st_mtime != d->file->last_mtime)